@@ -1,13 +1,15 @@
 """C4 Model Language entrypoint."""
 
+from typing import Iterable
+
 import gaphor.C4Model.grouping  # noqa
 import gaphor.C4Model.iconname  # noqa
 import gaphor.C4Model.propertypages  # noqa
 from gaphor.abc import ModelingLanguage
 from gaphor.C4Model import c4model, diagramitems
-from gaphor.C4Model.toolbox import c4model_toolbox_actions
+from gaphor.C4Model.toolbox import c4model_diagram_types, c4model_toolbox_actions
 from gaphor.core import gettext
-from gaphor.diagram.diagramtoolbox import ToolboxDefinition
+from gaphor.diagram.diagramtoolbox import DiagramType, ToolboxDefinition
 
 
 class C4ModelLanguage(ModelingLanguage):
@@ -19,6 +21,10 @@ class C4ModelLanguage(ModelingLanguage):
     def toolbox_definition(self) -> ToolboxDefinition:
         return c4model_toolbox_actions
 
+    @property
+    def diagram_types(self) -> Iterable[DiagramType]:
+        yield from c4model_diagram_types
+
     def lookup_element(self, name):
         element_type = getattr(c4model, name, None)
         if not element_type:
