@@ -6,14 +6,16 @@ from gaphas.item import SE
 from gaphor.C4Model import c4model, diagramitems
 from gaphor.core import gettext
 from gaphor.diagram.diagramtoolbox import (
+    DiagramType,
+    DiagramTypes,
     ToolboxDefinition,
     ToolDef,
     ToolSection,
     default_namespace,
     general_tools,
     namespace_config,
+    new_item_factory,
 )
-from gaphor.diagram.tools import new_item_factory
 from gaphor.UML import diagramitems as uml_items
 from gaphor.UML.actions.actionstoolbox import actions
 from gaphor.UML.classes.classestoolbox import classes
@@ -133,3 +135,11 @@ c4model_toolbox_actions: ToolboxDefinition = (
     interactions,
     states,
 )
+
+c4model_diagram_types: DiagramTypes = (
+    DiagramType("c4", gettext("New C4 Diagram"), (c4,)),
+    DiagramType("cls", gettext("New Class Diagram"), (classes,)),
+    DiagramType("act", gettext("New Activity Diagram"), (actions,)),
+    DiagramType("sd", gettext("New Sequence Diagram"), (interactions,)),
+    DiagramType("stm", gettext("New State Machine Diagram"), (states,)),
+)
