@@ -24,7 +24,7 @@ from gaphor.UML.classes.klass import (
     stereotype_compartments,
     stereotype_watches,
 )
-from gaphor.UML.modelfactory import stereotypes_str
+from gaphor.UML.recipes import stereotypes_str
 
 
 @represents(Requirement)
@@ -124,7 +124,7 @@ class RequirementItem(ElementPresentation[Requirement], Classified):
                     if subject and subject.text
                     else []
                 ),
-                style={"padding": (4, 4, 4, 4)},
+                style={"padding": (4, 4, 4, 4), "min-height": 8},
                 draw=draw_top_separator,
             )
         else:
