@@ -7,7 +7,7 @@ from gaphor.core.modeling import DrawContext
 from gaphor.core.modeling.properties import association
 from gaphor.core.styling import VerticalAlign
 from gaphor.diagram.presentation import ElementPresentation
-from gaphor.diagram.shapes import Box, cairo_state, stroke
+from gaphor.diagram.shapes import Box, stroke
 from gaphor.diagram.support import represents
 from gaphor.diagram.text import Layout
 
@@ -23,15 +23,16 @@ class PartitionItem(ElementPresentation):
         self.shape = Box(
             style={
                 "line-width": 2.4,
-                "padding": (2, 2, 2, 2),
+                "padding": (4, 12, 4, 12),
                 "vertical-align": VerticalAlign.TOP,
             },
             draw=self.draw_swimlanes,
         )
         self.watch("subject[NamedElement].name")
         self.watch("subject.appliedStereotype.classifier.name")
-        self.watch("partition.name")
         self.watch("partition", self.update_partition)
+        self.watch("partition.name")
+        self.watch("partition[ActivityPartition].represents[NamedElement].name")
 
     partition = association("partition", UML.ActivityPartition, composite=True)
 
@@ -55,50 +56,40 @@ class PartitionItem(ElementPresentation):
         """
         cr = context.cairo
         cr.set_line_width(context.style["line-width"])
-        self.draw_outline(bounding_box, context)
-        self.draw_partitions(bounding_box, context)
-        stroke(context)
-        self.draw_hover(bounding_box, context)
+        partitions = self.partition
 
-    def draw_hover(self, bounding_box: Rectangle, context: DrawContext) -> None:
-        """Add dashed line on bottom of swimlanes when hovered."""
-        if context.hovered or context.dropzone:
-            cr = context.cairo
-            with cairo_state(cr):
-                cr.set_dash((1.0, 5.0), 0)
-                cr.set_line_width(1.0)
-                cr.rectangle(0, 0, bounding_box.width, bounding_box.height)
-                cr.stroke()
-
-    def draw_partitions(self, bounding_box: Rectangle, context: DrawContext) -> None:
-        """Draw partition separators and add the name."""
-        cr = context.cairo
-        if self.partition:
-            partition_width = bounding_box.width / len(self.partition)
+        if partitions:
+            partition_width = bounding_box.width / len(partitions)
         else:
             partition_width = bounding_box.width / 2
-        layout = Layout()
-        style = context.style
-        padding_top = context.style["padding"][0]
-        for num, partition in enumerate(self.partition):
+
+        padding_top, padding_right, padding_bottom, padding_left = context.style[
+            "padding"
+        ]
+        layout = Layout(
+            font=context.style,
+            width=partition_width - padding_left - padding_right,
+        )
+        header_height = 0.0
+        for num, partition in enumerate(partitions):
             cr.move_to(partition_width * num, 0)
             cr.line_to(partition_width * num, bounding_box.height)
-            layout.set(text=partition.name, font=style)
-            cr.move_to(partition_width * num, padding_top * 3)
-            layout.show_layout(
-                cr,
-                partition_width,
-                default_size=(partition_width, HEADER_HEIGHT),
+            layout.set(
+                text=f"{partition.name}: {partition.represents.name}"
+                if isinstance(partition.represents, UML.NamedElement)
+                else partition.name
             )
+            cr.move_to(partition_width * num + padding_left, padding_top)
+            layout.show_layout(cr)
+            _, h = layout.size()
+            header_height = max(h, header_height)
 
-    def draw_outline(self, bounding_box: Rectangle, context: DrawContext) -> None:
-        """Draw the outline and header of the swimlanes."""
-        cr = context.cairo
-        cr.move_to(0, bounding_box.height)
-        cr.line_to(0, 0)
-        cr.line_to(bounding_box.width, 0)
+        cr.move_to(bounding_box.width, 0)
         cr.line_to(bounding_box.width, bounding_box.height)
-        cr.move_to(0, bounding_box.height)
-        cr.line_to(0, HEADER_HEIGHT)
-        cr.line_to(0 + bounding_box.width, HEADER_HEIGHT)
-        cr.line_to(0 + bounding_box.width, bounding_box.height)
+
+        header_height += padding_top + padding_bottom
+        cr.move_to(0, 0)
+        cr.line_to(0 + bounding_box.width, 0)
+        cr.move_to(0, header_height)
+        cr.line_to(0 + bounding_box.width, header_height)
+        stroke(context)
