@@ -65,7 +65,7 @@ class EnumerationItem(ElementPresentation[UML.Enumeration], Classified):
         self.shape = Box(
             Box(
                 Text(
-                    text=lambda: UML.model.stereotypes_str(
+                    text=lambda: UML.recipes.stereotypes_str(
                         self.subject, [gettext("enumeration")]
                     ),
                 ),
@@ -124,6 +124,6 @@ def enumerations_compartment(subject):
             )
             for literal in subject.ownedLiteral
         ),
-        style={"padding": (4, 4, 4, 4)},
+        style={"padding": (4, 4, 4, 4), "min-height": 8},
         draw=draw_top_separator,
     )
