@@ -2,6 +2,9 @@
 
 from typing import Optional
 
+from gaphas.connector import ConnectionSink, ItemConnectionSink
+from gaphas.types import Pos, SupportsFloatPos
+
 from gaphor import UML
 from gaphor.core.modeling import Element, Presentation
 from gaphor.diagram.connectors import BaseConnector, Connector
@@ -254,7 +257,7 @@ class LifelineExecutionSpecificationConnect(BaseConnector):
 
         diagram = self.diagram
         if self.line.parent is not self.element:
-            self.line.parent = self.element
+            self.line.change_parent(self.element)
 
         for cinfo in diagram.connections.get_connections(connected=self.line):
             Connector(self.line, cinfo.item).connect(cinfo.handle, cinfo.port)
@@ -270,7 +273,7 @@ class LifelineExecutionSpecificationConnect(BaseConnector):
 
         if self.line.parent is self.element:
             new_parent = self.element.parent
-            self.line.parent = new_parent
+            self.line.change_parent(new_parent)
 
         for cinfo in diagram.connections.get_connections(connected=self.line):
             Connector(self.line, cinfo.item).disconnect(cinfo.handle)
@@ -294,7 +297,7 @@ class ExecutionSpecificationExecutionSpecificationConnect(BaseConnector):
         assert connected_item
         Connector(connected_item, self.line).connect(handle, None)
 
-        self.line.parent = self.element
+        self.line.change_parent(self.element)
 
         return True
 
@@ -306,3 +309,25 @@ class ExecutionSpecificationExecutionSpecificationConnect(BaseConnector):
 
         for cinfo in self.diagram.connections.get_connections(connected=self.line):
             Connector(self.line, cinfo.item).disconnect(cinfo.handle)
+
+
+@ConnectionSink.register(LifelineItem)
+class LifelineConnectionSink(ItemConnectionSink):
+    def glue(
+        self, pos: SupportsFloatPos, secondary_pos: Optional[SupportsFloatPos] = None
+    ) -> Optional[Pos]:
+        """Glue a line to the lifeline item, have a preference for the lifetime
+        line."""
+        assert isinstance(self.item, LifelineItem)
+        glue_pos = super().glue(pos, secondary_pos)
+
+        lifetime = self.item.lifetime
+        if lifetime.visible and self.port is not lifetime.port:  # type: ignore[has-type]
+            g, d = lifetime.port.glue(pos)
+            if d < self.distance:
+                self.port = lifetime.port
+                glue_pos = g
+
+            return glue_pos
+
+        return glue_pos
