@@ -1,11 +1,13 @@
 """The UML Modeling Language module is the entrypoint for UML related
 assets."""
 
+from typing import Iterable
+
 from gaphor.abc import ModelingLanguage
 from gaphor.core import gettext
-from gaphor.diagram.diagramtoolbox import ToolboxDefinition
+from gaphor.diagram.diagramtoolbox import DiagramType, ToolboxDefinition
 from gaphor.UML import diagramitems, uml
-from gaphor.UML.toolbox import uml_toolbox_actions
+from gaphor.UML.toolbox import uml_diagram_types, uml_toolbox_actions
 
 
 class UMLModelingLanguage(ModelingLanguage):
@@ -17,6 +19,11 @@ class UMLModelingLanguage(ModelingLanguage):
     def toolbox_definition(self) -> ToolboxDefinition:
         return uml_toolbox_actions
 
+    @property
+    def diagram_types(self) -> Iterable[DiagramType]:
+        """Return an iterator (id, name) for each diagram type."""
+        yield from uml_diagram_types
+
     def lookup_element(self, name):
         element_type = getattr(uml, name, None)
         if not element_type:
