@@ -80,24 +80,21 @@ class Application(Service, ActionProvider):
     def active_session(self):
         return self._active_session
 
-    def new_session(self, *, filename=None, services=None, force=False):
-        if filename is None:
+    def new_session(self, *, filename=None, template=None, services=None, force=False):
+        if filename is None and template is None:
             return self._new_session(services=services)
 
-        if not force:
+        if filename and not force:
             for session in self._sessions:
                 if session.filename == filename:
                     session.foreground()
                     return
 
-        if not self._active_session or not self._active_session.is_new:
-            return self._new_session(filename=filename, services=services)
+        return self._new_session(
+            filename=filename, template=template, services=services
+        )
 
-        file_manager = self._active_session.get_service("file_manager")
-        file_manager.load(filename)
-        return self._active_session
-
-    def _new_session(self, filename=None, services=None):
+    def _new_session(self, filename=None, template=None, services=None):
         """Initialize an application session."""
         session = Session(services=services)
 
@@ -116,11 +113,11 @@ class Application(Service, ActionProvider):
         event_manager.subscribe(on_session_shutdown)
 
         self._sessions.add(session)
-        self._active_session = session
 
-        session_created = SessionCreated(self, session, filename)
+        session_created = SessionCreated(self, session, filename, template)
         event_manager.handle(session_created)
         self.event_manager.handle(session_created)
+        session.foreground()
 
         return session
 
@@ -202,19 +199,6 @@ class Session(Service):
 
         self.event_manager.subscribe(self.on_filename_changed)
 
-    @property
-    def is_new(self):
-        """If it's a new model, there is no state change (undo & redo) and no
-        file name is defined."""
-        undo_manager = self.get_service("undo_manager")
-        file_manager = self.get_service("file_manager")
-
-        return (
-            not undo_manager.can_undo()
-            and not undo_manager.can_redo()
-            and not file_manager.filename
-        )
-
     def get_service(self, name):
         if not self.component_registry:
             raise NotInitializedError("Session is no longer alive")
