@@ -214,7 +214,7 @@ class attribute(umlproperty, Generic[T]):
             and not isinstance(value, self.type)
             and not isinstance(value, str)
         ):
-            raise AttributeError(
+            raise TypeError(
                 "Value should be of type %s" % hasattr(self.type, "__name__")
                 and self.type.__name__
                 or self.type
@@ -265,7 +265,7 @@ class enumeration(umlproperty):
 
     def load(self, obj, value):
         if value not in self.values:
-            raise AttributeError("Value should be one of %s" % str(self.values))
+            raise TypeError("Value should be one of %s" % str(self.values))
         setattr(obj, self._name, value)
 
     def unlink(self, obj):
@@ -273,7 +273,7 @@ class enumeration(umlproperty):
 
     def _set(self, obj, value):
         if value not in self.values:
-            raise AttributeError("Value should be one of %s" % str(self.values))
+            raise TypeError("Value should be one of %s" % str(self.values))
         old = self._get(obj)
         if value == old:
             return
@@ -332,7 +332,7 @@ class association(umlproperty):
 
     def load(self, obj, value):
         if not isinstance(value, self.type):
-            raise AttributeError(
+            raise TypeError(
                 "Value for %s should be of type %s (%s)"
                 % (self.name, self.type.__name__, type(value).__name__)
             )
@@ -376,7 +376,7 @@ class association(umlproperty):
         This method is called from the opposite association property.
         """
         if obj is value:
-            raise AttributeError(f"Can not set {obj}.{self.name} to itself")
+            raise TypeError(f"Can not set {obj}.{self.name} to itself")
 
         if self.upper == 1:
             self._set_one(obj, value, from_opposite)
@@ -385,7 +385,7 @@ class association(umlproperty):
 
     def _set_one(self, obj, value, from_opposite=False) -> None:
         if not (isinstance(value, self.type) or (value is None)):
-            raise AttributeError(
+            raise TypeError(
                 f"Value should be of type {self.type.__name__}, got a {type(value)} instead"
             )
 
@@ -411,7 +411,7 @@ class association(umlproperty):
 
     def _set_many(self, obj, value, from_opposite=False, from_load=False) -> None:
         if not isinstance(value, self.type):
-            raise AttributeError(f"Value should be of type {self.type.__name__}")
+            raise TypeError(f"Value should be of type {self.type.__name__}")
 
         # Set the actual value
         c: collection = self._get_many(obj)
@@ -601,14 +601,19 @@ class derived(umlproperty, Generic[T]):
         self.lower = lower
         self.upper = upper
         self.filter = filter
-        self.subsets = set(subsets)
-        self.single = len(subsets) == 1
+        self.subsets: set[umlproperty] = set()
+        self.single = False
 
         for s in subsets:
-            assert isinstance(
-                s, (association, derived)
-            ), f"have element {s}, expected association"
-            s._dependent_properties.add(self)
+            self.add(s)
+
+    def add(self, subset):
+        self.subsets.add(subset)
+        self.single = len(self.subsets) == 1
+        assert isinstance(
+            subset, (association, derived)
+        ), f"have element {subset}, expected association"
+        subset._dependent_properties.add(self)
 
     def load(self, obj, value):
         raise ValueError(
@@ -660,10 +665,10 @@ class derived(umlproperty, Generic[T]):
         return uc.data
 
     def _set(self, obj, value):
-        raise AttributeError("Can not set values on a union")
+        raise AttributeError(f"Can not set values on union {self.name}: {self.type}")
 
     def _del(self, obj, value=None):
-        raise AttributeError("Can not delete values on a union")
+        raise AttributeError(f"Can not delete values on union {self.name}: {self.type}")
 
     def propagate(self, event):
         """Re-emit state change for the derived properties as Derived*Event's.
@@ -678,7 +683,6 @@ class derived(umlproperty, Generic[T]):
             if value not in derived union and
         """
         if event.property not in self.subsets:
-
             return
         if not isinstance(event, AssociationUpdated):
             return
@@ -690,7 +694,7 @@ class derived(umlproperty, Generic[T]):
             # assert isinstance(
             #     event, AssociationSet
             # ), f"Can only handle [0..1] set-events, not {event} for {event.element}"
-            old_value = self._get(event.element)
+            old_value = hasattr(event.element, self._name) and self._get(event.element)
             # Make sure unions are created again
             self.version += 1
             new_value = self._get(event.element)
@@ -739,8 +743,8 @@ class derivedunion(derived[T]):
         self,
         name: str,
         type: type[T],
-        lower: Lower,
-        upper: Upper,
+        lower: Lower = 0,
+        upper: Upper = "*",
         *subsets: relation,
     ):
         super().__init__(name, type, lower, upper, self._union, *subsets)
@@ -881,7 +885,7 @@ class redefine(umlproperty):
 
     def _set(self, obj, value, from_opposite=False):
         if not (isinstance(value, self.type) or (self.upper == 1 and value is None)):
-            raise AttributeError(
+            raise TypeError(
                 f"Value should be of type {self.type.__name__}, got a {type(value)} instead"
             )
         assert isinstance(self.original, association)
