@@ -1,10 +1,6 @@
+from gaphor.diagram.general import connectors, generaleditors, generalpropertypages
 from gaphor.diagram.general.comment import CommentItem
 from gaphor.diagram.general.commentline import CommentLineItem
 from gaphor.diagram.general.simpleitem import Box, Ellipse, Line
 
-
-def _load():
-    from gaphor.diagram.general import connectors, generaleditors, generalpropertypages
-
-
-_load()
+__all__ = ["CommentItem", "CommentLineItem", "Box", "Ellipse", "Line"]
