@@ -1,22 +1,31 @@
+import functools
+import importlib.metadata
 import inspect
 import logging
 from typing import Dict, Type, TypeVar
 
-import importlib_metadata
-
 T = TypeVar("T")
 
 logger = logging.getLogger(__name__)
 
 
 def initialize(scope, services=None, **known_services: T) -> Dict[str, T]:
-    return init_entrypoints(load_entrypoints(scope, services), **known_services)
+    return init_entry_points(load_entry_points(scope, services), **known_services)
 
 
-def load_entrypoints(scope, services=None) -> Dict[str, Type[T]]:
+@functools.lru_cache(maxsize=4)
+def list_entry_points(group):
+    try:
+        return importlib.metadata.entry_points(group=group)  # type: ignore[call-arg]
+    except TypeError:
+        # Fallback for Python < 3.10
+        return importlib.metadata.entry_points()[group]
+
+
+def load_entry_points(scope, services=None) -> Dict[str, Type[T]]:
     """Load services from resources."""
     uninitialized_services = {}
-    for ep in importlib_metadata.entry_points(group=scope):
+    for ep in list_entry_points(scope):
         cls = ep.load()
         if not services or ep.name in services:
             logger.debug(f'found service entry point "{ep.name}"')
@@ -24,7 +33,7 @@ def load_entrypoints(scope, services=None) -> Dict[str, Type[T]]:
     return uninitialized_services
 
 
-def init_entrypoints(
+def init_entry_points(
     uninitialized_services: Dict[str, Type[T]], **known_services: T
 ) -> Dict[str, T]:
     """Instantiate service definitions, taking into account dependencies
