@@ -7,7 +7,7 @@ from gi.repository import Gdk, Gtk
 from gaphor.abc import ActionProvider, Service
 from gaphor.core import Transaction, action
 from gaphor.core.modeling import Presentation
-from gaphor.diagram.copypaste import copy, paste
+from gaphor.diagram.copypaste import copy, paste_full, paste_link
 from gaphor.ui.event import DiagramSelectionChanged
 
 copy_buffer: object = None
@@ -59,11 +59,25 @@ class CopyService(Service, ActionProvider):
         if items:
             copy_buffer = copy(items)
 
-    def paste(self, diagram):
+    def paste_link(self, diagram):
         """Paste items in the copy-buffer to the diagram."""
         with Transaction(self.event_manager):
             # Create new id's that have to be used to create the items:
-            new_items: Set[Presentation] = paste(
+            new_items: Set[Presentation] = paste_link(
+                copy_buffer, diagram, self.element_factory.lookup
+            )
+
+            # move pasted items a bit, so user can see result of his action :)
+            for item in new_items:
+                if item.parent not in new_items:
+                    item.matrix.translate(10, 10)
+
+        return new_items
+
+    def paste_full(self, diagram):
+        with Transaction(self.event_manager):
+            # Create new id's that have to be used to create the items:
+            new_items: Set[Presentation] = paste_full(
                 copy_buffer, diagram, self.element_factory.lookup
             )
 
@@ -96,8 +110,15 @@ class CopyService(Service, ActionProvider):
                 for i in list(items):
                     i.unlink()
 
-    @action(name="edit-paste", shortcut="<Primary>v")
-    def paste_action(self):
+    @action(name="edit-paste-link", shortcut="<Primary>v")
+    def paste_link_action(self):
+        self._paste_action(self.paste_link)
+
+    @action(name="edit-paste-full", shortcut="<Primary><Shift>v")
+    def paste_full_action(self):
+        self._paste_action(self.paste_full)
+
+    def _paste_action(self, paster):
         view = self.diagrams.get_current_view()
         diagram = self.diagrams.get_current_diagram()
         if not (view and view.is_focus()):
@@ -106,7 +127,7 @@ class CopyService(Service, ActionProvider):
         if not copy_buffer:
             return
 
-        new_items = self.paste(diagram)
+        new_items = paster(diagram)
 
         selection = view.selection
         selection.unselect_all()
