@@ -1,4 +1,4 @@
-from typing import Dict
+from typing import Dict, Iterable
 
 from gaphor.abc import ActionProvider, ModelingLanguage, Service
 from gaphor.action import action
@@ -35,14 +35,16 @@ class ModelingLanguageService(Service, ActionProvider, ModelingLanguage):
         self.event_manager.unsubscribe(self.on_property_changed)
 
     @property
-    def modeling_languages(self):
-        """A Generator, returns tuples (id, localized name)."""
+    def modeling_languages(self) -> Iterable[tuple[str, str]]:
+        """An Iterator, returns tuples (id, localized name)."""
         for id, provider in self._modeling_languages.items():
-            yield id, provider.name
+            if provider.name:
+                yield id, provider.name
 
     @property
-    def active_modeling_language(self):
-        modeling_language = self.properties.get(
+    def active_modeling_language(self) -> str:
+        """The identifier for the currently active modeling language."""
+        modeling_language: str = self.properties.get(
             "modeling-language", self.DEFAULT_LANGUAGE
         )
         if modeling_language not in self._modeling_languages:
@@ -50,38 +52,38 @@ class ModelingLanguageService(Service, ActionProvider, ModelingLanguage):
         return modeling_language
 
     @property
-    def active_modeling_language_name(self):
-        return self._modeling_languages[self.active_modeling_language].name
-
-    @property
-    def _modeling_language(self):
-        return self._modeling_languages[self.active_modeling_language]
-
-    @property
-    def name(self):
-        return self._modeling_language.name
+    def name(self) -> str:
+        """Localized name of the active modeling language."""
+        return self._modeling_language().name
 
     @property
     def toolbox_definition(self):
-        return self._modeling_language.toolbox_definition
+        return self._modeling_language().toolbox_definition
+
+    @property
+    def diagram_types(self):
+        return self._modeling_language().diagram_types
 
     def lookup_element(self, name):
-        return self.first(lambda provider: provider.lookup_element(name))
+        return next(
+            filter(
+                None,
+                map(
+                    lambda provider: provider.lookup_element(name),
+                    self._modeling_languages.values(),
+                ),
+            ),
+            None,
+        )
 
-    def first(self, predicate):
-        for _, provider in self._modeling_languages.items():
-            type = predicate(provider)
-            if type:
-                return type
-
-    @action(
-        name="select-modeling-language",
-        state=lambda self: self.active_modeling_language,
-    )
-    def action_select_modeling_language(self, modeling_language: str):
+    @action(name="select-modeling-language")
+    def select_modeling_language(self, modeling_language: str):
         self.properties.set("modeling-language", modeling_language)
         self.event_manager.handle(ModelingLanguageChanged(modeling_language))
 
+    def _modeling_language(self) -> ModelingLanguage:
+        return self._modeling_languages[self.active_modeling_language]
+
     @event_handler(PropertyChanged)
     def on_property_changed(self, event: PropertyChanged):
         if event.key == "modeling-language":
