@@ -43,7 +43,7 @@ def get_cache_dir() -> str:
 
 
 def file_hash(filename: str) -> str:
-    return hashlib.blake2b(filename.encode("utf-8"), digest_size=24).hexdigest()
+    return hashlib.blake2b(str(filename).encode("utf-8"), digest_size=24).hexdigest()
 
 
 class PropertyChanged:
@@ -128,7 +128,7 @@ class Properties(Service):
                 data = ifile.read()
 
             self._properties = ast.literal_eval(data)
-            for key, value in self._properties.items():
+            for key, value in list(self._properties.items()):
                 self.event_manager.handle(PropertyChanged(key, None, value))
 
     def save(self):
