@@ -1,43 +1,45 @@
 """This module contains user interface related code, such as the main screen
 and diagram windows."""
 
-import importlib.resources
 import logging
+import os
 import sys
 from pathlib import Path
 from typing import Optional
 
+import gi
+
+if os.getenv("GAPHOR_USE_GTK") != "NONE":
+    # Allow to explicitly *not* initialize GTK (for docs, mainly)
+    gtk_version = "4.0" if os.getenv("GAPHOR_USE_GTK") == "4" else "3.0"
+    gtk_source_version = "5" if os.getenv("GAPHOR_USE_GTK") == "4" else "4"
+
+    if gtk_version == "4.0":
+        # Monkey patch PyGObject
+        import gi.overrides.Gtk
+
+        del gi.overrides.Gtk.TreeView.enable_model_drag_source
+        del gi.overrides.Gtk.TreeView.enable_model_drag_dest
+        gi.overrides.Gtk.ListStore.insert_with_valuesv = (
+            gi.overrides.Gtk.ListStore.insert_with_values
+        )
+
+    gi.require_version("Gtk", gtk_version)
+    gi.require_version("Gdk", gtk_version)
+    if gtk_version == "3.0":
+        gi.require_version("GtkSource", gtk_source_version)
+
+
 from gi.repository import Gdk, Gio, GLib, Gtk
 
-from gaphor.application import Application, Session
+from gaphor.application import Application, Session, distribution
 from gaphor.core import event_handler
 from gaphor.event import ActiveSessionChanged, ApplicationShutdown, SessionCreated
 from gaphor.ui.actiongroup import apply_application_actions
 from gaphor.ui.macosshim import macos_init
 
 APPLICATION_ID = "org.gaphor.Gaphor"
-
-
-icon_theme = (
-    Gtk.IconTheme.get_default()
-    if Gtk.get_major_version() == 3
-    else Gtk.IconTheme.get_for_display(Gdk.Display.get_default())
-)
-if sys.version_info >= (3, 9):
-    path: Path = importlib.resources.files("gaphor") / "ui" / "icons"  # type: ignore[assignment]
-    # FixMe: check is only needed for RtD.
-    if icon_theme:
-        if Gtk.get_major_version() == 3:
-            icon_theme.append_search_path(str(path))
-        else:
-            icon_theme.add_search_path(str(path))
-else:
-    with importlib.resources.path("gaphor.ui", "icons") as path:
-        if Gtk.get_major_version() == 3:
-            icon_theme.append_search_path(str(path))
-        else:
-            icon_theme.add_search_path(str(path))
-
+HOME = str(Path.home())
 LOG_FORMAT = "%(name)s %(levelname)s %(message)s"
 
 
@@ -54,7 +56,11 @@ def main(argv=sys.argv):
     def has_option(*options):
         return any(o in argv for o in options)
 
-    if has_option("-v", "--verbose"):
+    if has_option("-v", "--version"):
+        print(f"Gaphor {distribution().version}")
+        return
+
+    if has_option("-d", "--debug"):
         logging.basicConfig(level=logging.INFO, format=LOG_FORMAT)
         logging.getLogger("gaphor").setLevel(logging.DEBUG)
     elif has_option("-q", "--quiet"):
@@ -67,14 +73,10 @@ def main(argv=sys.argv):
         import cProfile
         import pstats
 
-        cProfile.runctx(
-            "run(argv)",
-            globals(),
-            locals(),
-            filename="gaphor.prof",
-        )
+        with cProfile.Profile() as profile:
+            profile.runcall(run, argv)
 
-        profile_stats = pstats.Stats("gaphor.prof")
+        profile_stats = pstats.Stats(profile)
         profile_stats.strip_dirs().sort_stats("time").print_stats(50)
 
     else:
@@ -113,6 +115,7 @@ def run(args):
             event_manager = application.get_service("event_manager")
             event_manager.subscribe(on_session_created)
             event_manager.subscribe(on_quit)
+            application.get_service("greeter").init(gtk_app)
         except Exception:
             gtk_app.quit()
             raise
@@ -120,7 +123,7 @@ def run(args):
     def app_activate(gtk_app):
         assert application
         if not application.has_sessions():
-            application.new_session()
+            application.get_service("greeter").open()
 
     def app_open(gtk_app, files, n_files, hint):
         # appfilemanager should take care of this:
@@ -147,11 +150,19 @@ def add_main_options(gtk_app):
     Define them here, so they show up on `gaphor --help`.
     """
     gtk_app.add_main_option(
-        "verbose",
+        "version",
         ord("v"),
         GLib.OptionFlags.NONE,
         GLib.OptionArg.NONE,
-        "Verbose output",
+        "Print version and exit",
+        None,
+    )
+    gtk_app.add_main_option(
+        "debug",
+        ord("d"),
+        GLib.OptionFlags.NONE,
+        GLib.OptionArg.NONE,
+        "Debug output",
         None,
     )
     gtk_app.add_main_option(
