@@ -13,16 +13,22 @@ from gi.repository import Gdk, GdkPixbuf, Gtk
 from gaphor import UML
 from gaphor.core import event_handler, gettext
 from gaphor.core.modeling import StyleSheet
-from gaphor.core.modeling.diagram import StyledDiagram
+from gaphor.core.modeling.diagram import Diagram, StyledDiagram
 from gaphor.core.modeling.event import AttributeUpdated, ElementDeleted
-from gaphor.diagram.diagramtoolbox import tooliter
-from gaphor.diagram.painter import ItemPainter
+from gaphor.diagram.diagramtoolbox import get_tool_def, tooliter
+from gaphor.diagram.painter import DiagramTypePainter, ItemPainter
 from gaphor.diagram.selection import Selection
 from gaphor.diagram.support import get_diagram_item
-from gaphor.diagram.tools import apply_default_tool_set, apply_placement_tool_set
+from gaphor.diagram.tools import (
+    apply_default_tool_set,
+    apply_magnet_tool_set,
+    apply_placement_tool_set,
+)
+from gaphor.diagram.tools.magnet import MagnetPainter
 from gaphor.diagram.tools.placement import create_item, open_editor
+from gaphor.event import Notification
 from gaphor.transaction import Transaction
-from gaphor.ui.event import DiagramSelectionChanged, Notification, ToolSelected
+from gaphor.ui.event import DiagramSelectionChanged, ToolSelected
 
 log = logging.getLogger(__name__)
 
@@ -57,40 +63,37 @@ if Gtk.get_major_version() == 3:
             _placement_pixbuf_map[icon_name] = pixbuf
         return Gdk.Cursor.new_from_pixbuf(display, pixbuf, 1, 1)
 
-
 else:
-    _placement_texture_map: Dict[str, Gdk.Texture] = {}
 
-    def get_placement_cursor(display, icon_name):
+    @functools.lru_cache(maxsize=None)
+    def get_placement_icon(display, icon_name):
         if display is None:
             display = Gdk.Display.get_default()
-        if icon_name in _placement_texture_map:
-            texture = _placement_texture_map[icon_name]
-        else:
-            pixbuf = placement_icon_base().copy()
-            theme_icon = Gtk.IconTheme.get_for_display(display).lookup_icon(
-                icon_name,
-                None,
-                24,
-                1,
-                Gtk.TextDirection.NONE,
-                Gtk.IconLookupFlags.FORCE_SYMBOLIC,
-            )
-            icon = GdkPixbuf.Pixbuf.new_from_file_at_scale(
-                theme_icon.get_file().get_path(), 32, 32, True
-            )
-            icon.copy_area(
-                0,
-                0,
-                icon.get_width(),
-                icon.get_height(),
-                pixbuf,
-                9,
-                15,
-            )
-            texture = Gdk.Texture.new_for_pixbuf(pixbuf)
-            _placement_texture_map[icon_name] = texture
-        return Gdk.Cursor.new_from_texture(texture, 1, 1)
+        pixbuf = placement_icon_base().copy()
+        theme_icon = Gtk.IconTheme.get_for_display(display).lookup_icon(
+            icon_name,
+            None,
+            24,
+            1,
+            Gtk.TextDirection.NONE,
+            Gtk.IconLookupFlags.FORCE_SYMBOLIC,
+        )
+        icon = GdkPixbuf.Pixbuf.new_from_file_at_scale(
+            theme_icon.get_file().get_path(), 32, 32, True
+        )
+        icon.copy_area(
+            0,
+            0,
+            icon.get_width(),
+            icon.get_height(),
+            pixbuf,
+            9,
+            15,
+        )
+        return Gdk.Texture.new_for_pixbuf(pixbuf)
+
+    def get_placement_cursor(display, icon_name):
+        return Gdk.Cursor.new_from_texture(get_placement_icon(display, icon_name), 1, 1)
 
 
 class DiagramPage:
@@ -120,7 +123,7 @@ class DiagramPage:
         self.rubberband_state = RubberbandState()
 
         self.event_manager.subscribe(self._on_element_delete)
-        self.event_manager.subscribe(self._on_style_sheet_updated)
+        self.event_manager.subscribe(self._on_attribute_updated)
         self.event_manager.subscribe(self._on_tool_selected)
 
     title = property(lambda s: s.diagram and s.diagram.name or gettext("<None>"))
@@ -145,9 +148,6 @@ class DiagramPage:
                 DiagramPage.VIEW_DND_TARGETS,
                 Gdk.DragAction.MOVE | Gdk.DragAction.COPY | Gdk.DragAction.LINK,
             )
-        else:
-            # TODO: GTK4 - use controllers DragSource and DropTarget
-            ...
 
         self.diagram_css = Gtk.CssProvider.new()
         view.get_style_context().add_provider(
@@ -177,13 +177,6 @@ class DiagramPage:
 
         return self.widget
 
-    def get_tool_def(self, tool_name):
-        return next(
-            t
-            for t in tooliter(self.modeling_language.toolbox_definition)
-            if t.id == tool_name
-        )
-
     def apply_tool_set(self, tool_name):
         """Return a tool associated with an id (action name)."""
         if tool_name == "toolbox-pointer":
@@ -193,8 +186,14 @@ class DiagramPage:
                 self.event_manager,
                 self.rubberband_state,
             )
+        elif tool_name == "toolbox-magnet":
+            return apply_magnet_tool_set(
+                self.view,
+                self.modeling_language,
+                self.event_manager,
+            )
 
-        tool_def = self.get_tool_def(tool_name)
+        tool_def = get_tool_def(self.modeling_language, tool_name)
         item_factory = tool_def.item_factory
         handle_index = tool_def.handle_index
         return apply_placement_tool_set(
@@ -206,7 +205,7 @@ class DiagramPage:
         )
 
     def get_tool_icon_name(self, tool_name):
-        if tool_name == "toolbox-pointer":
+        if tool_name in ("toolbox-pointer", "toolbox-magnet"):
             return None
         return next(
             t
@@ -224,13 +223,15 @@ class DiagramPage:
             self.close()
 
     @event_handler(AttributeUpdated)
-    def _on_style_sheet_updated(self, event: AttributeUpdated):
+    def _on_attribute_updated(self, event: AttributeUpdated):
         if event.property is StyleSheet.styleSheet:
             self.set_drawing_style()
 
             diagram = self.diagram
             for item in diagram.get_all_items():
                 diagram.request_update(item)
+        elif event.property is Diagram.name and self.view:
+            self.view.update_back_buffer()
 
     def close(self):
         """Tab is destroyed.
@@ -246,7 +247,7 @@ class DiagramPage:
                 parent.remove(self.widget)
 
         self.event_manager.unsubscribe(self._on_element_delete)
-        self.event_manager.unsubscribe(self._on_style_sheet_updated)
+        self.event_manager.unsubscribe(self._on_attribute_updated)
         self.event_manager.unsubscribe(self._on_tool_selected)
         self.view = None
 
@@ -272,7 +273,7 @@ class DiagramPage:
         assert self.view
         assert self.diagram_css
 
-        style = self.diagram.style(StyledDiagram(self.diagram, self.view))
+        style = self.diagram.style(StyledDiagram(self.diagram))
 
         bg = style.get("background-color")
         # Default background to white, slightly gray in dark mode
@@ -297,7 +298,9 @@ class DiagramPage:
             .append(HandlePainter(view))
             .append(LineSegmentPainter(view.selection))
             .append(GuidePainter(view))
+            .append(MagnetPainter(view))
             .append(RubberbandPainter(self.rubberband_state))
+            .append(DiagramTypePainter(self.diagram))
         )
 
         view.request_update(self.diagram.get_all_items())
@@ -312,57 +315,61 @@ class DiagramPage:
             )
         )
 
-    def _on_drag_data_received(self, view, context, x, y, data, info, time):
-        """Handle data dropped on the diagram."""
-        if (
-            data
-            and data.get_format() == 8
-            and info == DiagramPage.VIEW_TARGET_TOOLBOX_ACTION
-        ):
-            tool_def = self.get_tool_def(data.get_data().decode())
-            with Transaction(self.event_manager):
-                item = create_item(view, tool_def.item_factory, x, y)
-            open_editor(item, view, self.event_manager)
-            context.finish(True, False, time)
-        elif (
-            data
-            and data.get_format() == 8
-            and info == DiagramPage.VIEW_TARGET_ELEMENT_ID
-        ):
-            element_id = data.get_data().decode()
-            element = self.element_factory.lookup(element_id)
-            assert element
+    if Gtk.get_major_version() == 3:
 
-            if not isinstance(
-                element, (UML.Classifier, UML.Package, UML.Property)
-            ) or isinstance(element, UML.Association):
-                self.event_manager.handle(
-                    Notification(
-                        gettext(
-                            "Drag to diagram is (temporarily) limited to Classifiers, Packages, and Properties, not {type}."
-                        ).format(type=type(element).__name__)
-                    )
+        def _on_drag_data_received(self, view, context, x, y, data, info, time):
+            """Handle data dropped on the diagram."""
+            if (
+                data
+                and data.get_format() == 8
+                and info == DiagramPage.VIEW_TARGET_TOOLBOX_ACTION
+            ):
+                tool_def = get_tool_def(
+                    self.modeling_language, data.get_data().decode()
                 )
-                context.finish(True, False, time)
-                return
-
-            item_class = get_diagram_item(type(element))
-            if item_class:
                 with Transaction(self.event_manager):
-                    item = self.diagram.create(item_class)
-                    assert item
+                    item = create_item(view, tool_def.item_factory, x, y)
+                open_editor(item, view, self.event_manager)
+                context.finish(True, False, time)
+            elif (
+                data
+                and data.get_format() == 8
+                and info == DiagramPage.VIEW_TARGET_ELEMENT_ID
+            ):
+                element_id = data.get_data().decode()
+                element = self.element_factory.lookup(element_id)
+                assert element
 
-                    x, y = view.get_matrix_v2i(item).transform_point(x, y)
-                    item.matrix.translate(x, y)
-                    item.subject = element
+                if not isinstance(
+                    element, (UML.Classifier, UML.Package, UML.Property)
+                ) or isinstance(element, UML.Association):
+                    self.event_manager.handle(
+                        Notification(
+                            gettext(
+                                "Drag to diagram is (temporarily) limited to Classifiers, Packages, and Properties, not {type}."
+                            ).format(type=type(element).__name__)
+                        )
+                    )
+                    context.finish(True, False, time)
+                    return
 
-                view.selection.unselect_all()
-                view.selection.focused_item = item
+                item_class = get_diagram_item(type(element))
+                if item_class:
+                    with Transaction(self.event_manager):
+                        item = self.diagram.create(item_class)
+                        assert item
 
+                        x, y = view.get_matrix_v2i(item).transform_point(x, y)
+                        item.matrix.translate(x, y)
+                        item.subject = element
+
+                    view.selection.unselect_all()
+                    view.selection.focused_item = item
+
+                else:
+                    log.warning(
+                        f"No graphical representation for element {type(element).__name__}"
+                    )
+                context.finish(True, False, time)
             else:
-                log.warning(
-                    f"No graphical representation for element {type(element).__name__}"
-                )
-            context.finish(True, False, time)
-        else:
-            context.finish(False, False, time)
+                context.finish(False, False, time)
