@@ -3,7 +3,7 @@
 import logging
 from typing import Optional
 
-from gi.repository import GLib, Gtk, GtkSource
+from gi.repository import GLib, Gtk
 
 from gaphor.abc import ActionProvider
 from gaphor.core import Transaction, action, event_handler
@@ -18,6 +18,10 @@ from gaphor.diagram.propertypages import PropertyPages, new_resource_builder
 from gaphor.ui.abc import UIComponent
 from gaphor.ui.event import DiagramSelectionChanged
 
+if Gtk.get_major_version() == 3:
+    from gi.repository import GtkSource
+
+
 log = logging.getLogger(__name__)
 
 
@@ -104,6 +108,13 @@ class ElementEditor(UIComponent, ActionProvider):
     def reset_tool_after_create(self, active):
         self.properties.set("reset-tool-after-create", active)
 
+    @action(
+        name="remove-unused-elements",
+        state=lambda self: self.properties.get("remove-unused-elements", True),
+    )
+    def remove_unused_elements(self, active):
+        self.properties.set("remove-unused-elements", active)
+
 
 class EditorStack:
     def __init__(self, event_manager, diagrams, properties):
@@ -247,7 +258,8 @@ class SettingsStack:
     def __init__(self, event_manager, element_factory):
         self.event_manager = event_manager
         self.element_factory = element_factory
-        self.lang_manager = GtkSource.LanguageManager.get_default()
+        if Gtk.get_major_version() == 3:
+            self.lang_manager = GtkSource.LanguageManager.get_default()
 
         def tx_update_style_sheet(style_sheet, text):
             self._in_update = 1
@@ -260,9 +272,11 @@ class SettingsStack:
 
     def open(self, builder):
         self.style_sheet_buffer = builder.get_object("style-sheet-buffer")
-        self.style_sheet_buffer.set_language(self.lang_manager.get_language("css"))
         self.style_sheet_view = builder.get_object("style-sheet-view")
 
+        if Gtk.get_major_version() == 3:
+            self.style_sheet_buffer.set_language(self.lang_manager.get_language("css"))
+
         self.event_manager.subscribe(self._model_ready)
         self.event_manager.subscribe(self._style_sheet_created)
         self.event_manager.subscribe(self._style_sheet_changed)
