@@ -11,6 +11,11 @@ class DiagramClosed:
         self.diagram = diagram
 
 
+class CurrentDiagramChanged:
+    def __init__(self, diagram):
+        self.diagram = diagram
+
+
 class DiagramSelectionChanged:
     def __init__(self, diagram_view, focused_item, selected_items):
         self.diagram_view = diagram_view
@@ -21,8 +26,3 @@ class DiagramSelectionChanged:
 class ToolSelected:
     def __init__(self, tool_name):
         self.tool_name = tool_name
-
-
-class Notification:
-    def __init__(self, message):
-        self.message = message
