@@ -9,7 +9,7 @@ from gi.repository import GLib, Gtk
 from gaphor import UML
 from gaphor.abc import ActionProvider, Service
 from gaphor.core import action, event_handler, gettext
-from gaphor.core.modeling.stylesheet import StyleSheet
+from gaphor.core.modeling import Diagram, StyleSheet
 from gaphor.event import (
     ModelLoaded,
     ModelSaved,
@@ -17,11 +17,10 @@ from gaphor.event import (
     SessionShutdown,
     SessionShutdownRequested,
 )
-from gaphor.storage import storage, verify
+from gaphor.storage import storage
 from gaphor.storage.xmlwriter import XMLWriter
 from gaphor.ui.errorhandler import error_handler
 from gaphor.ui.filedialog import GAPHOR_FILTER, save_file_dialog
-from gaphor.ui.questiondialog import QuestionDialog
 from gaphor.ui.statuswindow import StatusWindow
 
 DEFAULT_EXT = ".gaphor"
@@ -54,7 +53,7 @@ def load_default_model(element_factory):
         element_factory.create(StyleSheet)
         model = element_factory.create(UML.Package)
         model.name = gettext("New model")
-        diagram = element_factory.create(UML.Diagram)
+        diagram = element_factory.create(Diagram)
         diagram.element = model
         diagram.name = gettext("main")
     element_factory.model_ready()
@@ -82,14 +81,16 @@ class FileManager(Service, ActionProvider):
         self.event_manager.unsubscribe(self._on_session_shutdown_request)
         self.event_manager.unsubscribe(self._on_session_created)
 
-    def get_filename(self):
+    @property
+    def filename(self):
         """Return the current file name.
 
         This method is used by the filename property.
         """
         return self._filename
 
-    def set_filename(self, filename):
+    @filename.setter
+    def filename(self, filename):
         """Sets the current file name.
 
         This method is used by the filename property. Setting the
@@ -99,8 +100,6 @@ class FileManager(Service, ActionProvider):
         if filename != self._filename:
             self._filename = filename
 
-    filename = property(get_filename, set_filename)
-
     def load(self, filename):
         """Load the Gaphor model from the supplied file name.
 
@@ -113,27 +112,37 @@ class FileManager(Service, ActionProvider):
         self.filename = filename
         queue: Queue[int] = Queue(0)
         status_window = StatusWindow(
-            gettext("Loading..."),
+            gettext("Loading…"),
             gettext("Loading model from {filename}").format(filename=filename),
             parent=self.main_window.window,
             queue=queue,
         )
 
+        self._load(filename, ModelLoaded(self, filename), queue, status_window)
+
+    def load_template(self, template):
+        self._load(template, ModelLoaded(self))
+
+    def _load(self, filename, model_loaded_event, queue=None, status_window=None):
         # Use low prio, so screen updates do happen
         @g_async(priority=GLib.PRIORITY_DEFAULT_IDLE)
         def async_loader():
             try:
                 for percentage in storage.load_generator(
-                    filename.encode("utf-8"),
+                    filename,
                     self.element_factory,
                     self.modeling_language,
                 ):
-                    queue.put(percentage)
+                    if queue:
+                        queue.put(percentage)
                     yield percentage
 
-                self.event_manager.handle(ModelLoaded(self, filename))
+                self.event_manager.handle(model_loaded_event)
             except Exception:
                 self.filename = None
+                if status_window:
+                    status_window.destroy()
+                log.exception(f"Unable to open model “{filename}”.", stack_info=True)
                 error_handler(
                     message=gettext("Unable to open model “{filename}”.").format(
                         filename=filename
@@ -146,39 +155,12 @@ class FileManager(Service, ActionProvider):
                 load_default_model(self.element_factory)
                 raise
             finally:
-                status_window.destroy()
+                if status_window:
+                    status_window.destroy()
 
         for _ in async_loader():
             pass
 
-    def verify_orphans(self):
-        """Verify that no orphaned elements are saved.
-
-        This method checks of there are any orphan references in the
-        element factory.  If orphans are found, a dialog is displayed
-        asking the user if it is OK to unlink them.
-        """
-
-        orphans = verify.orphan_references(self.element_factory)
-
-        if orphans:
-            log.info("Found orphan references %s", orphans)
-            main_window = self.main_window
-
-            dialog = QuestionDialog(
-                gettext(
-                    "The model contains some references to items that are not maintained. Do you want to clean the model before saving?"
-                ),
-                parent=main_window.window,
-            )
-
-            answer = dialog.answer
-            dialog.destroy()
-
-            if not answer:
-                for orphan in orphans:
-                    orphan.unlink()
-
     def save(self, filename):
         """Save the current UML model to the specified file name.
 
@@ -191,12 +173,10 @@ class FileManager(Service, ActionProvider):
         if not (filename and len(filename)):
             return
 
-        self.verify_orphans()
-
         main_window = self.main_window
         queue: Queue[int] = Queue(0)
         status_window = StatusWindow(
-            gettext("Saving..."),
+            gettext("Saving…"),
             gettext("Saving model to {filename}").format(filename=filename),
             parent=main_window.window,
             queue=queue,
@@ -205,7 +185,7 @@ class FileManager(Service, ActionProvider):
         @g_async(priority=GLib.PRIORITY_DEFAULT_IDLE)
         def async_saver():
             try:
-                with open(filename.encode("utf-8"), "w") as out:
+                with open(filename, "w") as out:
                     for percentage in storage.save_generator(
                         XMLWriter(out), self.element_factory
                     ):
@@ -271,6 +251,8 @@ class FileManager(Service, ActionProvider):
     def _on_session_created(self, event: SessionCreated) -> None:
         if event.filename:
             self.load(event.filename)
+        elif event.template:
+            self.load_template(event.template)
         else:
             load_default_model(self.element_factory)
 
