@@ -13,12 +13,15 @@ from typing import TYPE_CHECKING
 from gi.repository import Gdk, Gio, GLib, Gtk
 
 from gaphor import UML
-from gaphor.abc import ActionProvider
-from gaphor.core import action, event_handler, gettext, transactional
+from gaphor.abc import ActionProvider, ModelingLanguage
+from gaphor.core import action, event_handler, gettext
 from gaphor.core.modeling import Diagram, Element, Presentation
+from gaphor.diagram.deletable import deletable
+from gaphor.transaction import Transaction
 from gaphor.ui.abc import UIComponent
 from gaphor.ui.actiongroup import create_action_group
 from gaphor.ui.event import DiagramOpened, DiagramSelectionChanged
+from gaphor.ui.mainwindow import create_diagram_types_model
 from gaphor.ui.namespacemodel import (
     RELATIONSHIPS,
     NamespaceModel,
@@ -35,7 +38,7 @@ if TYPE_CHECKING:
 log = logging.getLogger(__name__)
 
 
-def popup_model(element):
+def popup_model(element, modeling_language):
     model = Gio.Menu.new()
 
     part = Gio.Menu.new()
@@ -44,7 +47,9 @@ def popup_model(element):
     model.append_section(None, part)
 
     part = Gio.Menu.new()
-    part.append(gettext("New _Diagram"), "win.create-diagram")
+    part.append_submenu(
+        gettext("New _Diagram"), create_diagram_types_model(modeling_language)
+    )
     part.append(gettext("New _Package"), "tree-view.create-package")
     model.append_section(None, part)
 
@@ -60,7 +65,7 @@ def popup_model(element):
         diagram = presentation.diagram
         if diagram:
             menu_item = Gio.MenuItem.new(
-                gettext('Show in "{diagram}"').format(diagram=diagram.name),
+                gettext("Show in “{diagram}”").format(diagram=diagram.name),
                 "tree-view.show-in-diagram",
             )
             menu_item.set_attribute_value("target", GLib.Variant.new_string(diagram.id))
@@ -76,9 +81,15 @@ def popup_model(element):
 
 
 class Namespace(UIComponent, ActionProvider):
-    def __init__(self, event_manager: EventManager, element_factory: ElementFactory):
+    def __init__(
+        self,
+        event_manager: EventManager,
+        element_factory: ElementFactory,
+        modeling_language: ModelingLanguage,
+    ):
         self.event_manager = event_manager
         self.element_factory = element_factory
+        self.modeling_language = modeling_language
 
         self.model: NamespaceModel | None = None
         self.view: Gtk.TreeView | None = None
@@ -169,12 +180,14 @@ class Namespace(UIComponent, ActionProvider):
 
     def _on_show_popup(self, ctrl, n_press, x, y):
         if Gtk.get_major_version() == 3:
-            menu = Gtk.Menu.new_from_model(popup_model(self.get_selected_element()))
+            menu = Gtk.Menu.new_from_model(
+                popup_model(self.get_selected_element(), self.modeling_language)
+            )
             menu.attach_to_widget(self.view, None)
             menu.popup_at_pointer(None)
         else:
             menu = Gtk.PopoverMenu.new_from_model(
-                popup_model(self.get_selected_element())
+                popup_model(self.get_selected_element(), self.modeling_language)
             )
             menu.set_pointing_to(Gdk.Rectangle(x, y, 1, 1))
             menu.set_offset(x, y)
@@ -206,18 +219,7 @@ class Namespace(UIComponent, ActionProvider):
                 isinstance(element, UML.Package)
             )
             action_group.lookup_action("delete").set_enabled(
-                isinstance(
-                    element,
-                    (
-                        Diagram,
-                        UML.Package,
-                        UML.Interaction,
-                        UML.StateMachine,
-                        UML.Region,
-                        UML.Activity,
-                    ),
-                )
-                and not element.presentation
+                element and deletable(element)
             )
             action_group.lookup_action("rename").set_enabled(
                 isinstance(element, (Diagram, UML.NamedElement))
@@ -294,59 +296,47 @@ class Namespace(UIComponent, ActionProvider):
             cell.set_property("editable", 0)
 
     @action(name="win.create-diagram")
-    @transactional
-    def tree_view_create_diagram(self):
+    def tree_view_create_diagram(self, diagram_type: str):
         assert self.view
         element = self.get_selected_element()
-        diagram = self.element_factory.create(Diagram)
-        if isinstance(element, UML.NamedElement):
-            diagram.element = element
-            diagram.name = gettext("{name} diagram").format(name=element.name)
-        else:
-            diagram.name = gettext("New diagram")
+        while element and not isinstance(element, UML.NamedElement):
+            element = element.owner
+
+        with Transaction(self.event_manager):
+            diagram = self.element_factory.create(Diagram)
+            if isinstance(element, UML.NamedElement):
+                diagram.element = element
+            diagram.name = diagram_name_for_type(self.modeling_language, diagram_type)
+            diagram.diagramType = diagram_type
         self.select_element(diagram)
         self.event_manager.handle(DiagramOpened(diagram))
         self.tree_view_rename_selected()
 
     @action(name="tree-view.create-package")
-    @transactional
     def tree_view_create_package(self):
         element = self.get_selected_element()
         assert isinstance(element, UML.Package)
-        package = self.element_factory.create(UML.Package)
-        package.package = element
-
-        package.name = (
-            gettext("{name} package").format(name=element.name)
-            if element
-            else gettext("New model")
-        )
+        with Transaction(self.event_manager):
+            package = self.element_factory.create(UML.Package)
+            package.package = element
+            package.name = (
+                gettext("{name} package").format(name=element.name)
+                if element
+                else gettext("New model")
+            )
         self.select_element(package)
         self.tree_view_rename_selected()
 
     @action(name="tree-view.delete")
-    @transactional
     def tree_view_delete(self):
         element = self.get_selected_element()
-        if isinstance(element, Diagram):
-            m = Gtk.MessageDialog(
-                None,
-                Gtk.DialogFlags.MODAL,
-                Gtk.MessageType.QUESTION,
-                Gtk.ButtonsType.YES_NO,
-                gettext(
-                    "Do you really want to delete diagram {name}?\n\n"
-                    "This will possibly delete diagram items\n"
-                    "that are not shown in other diagrams."
-                ).format(name=element.name or gettext("<None>")),
-            )
-            if m.run() == Gtk.ResponseType.YES:
-                for i in reversed(list(element.get_all_items())):
-                    s = i.subject
-                    if s and len(s.presentation) == 1:
-                        s.unlink()
-                    i.unlink()
+        if element:
+            with Transaction(self.event_manager):
                 element.unlink()
-            m.destroy()
-        elif element:
-            element.unlink()
+
+
+def diagram_name_for_type(modeling_language, diagram_type):
+    for id, name, _ in modeling_language.diagram_types:
+        if id == diagram_type:
+            return name
+    return gettext("New diagram")
