@@ -37,6 +37,7 @@ def namespace_view(model: Gtk.TreeModel):
     selection = view.get_selection()
     selection.set_mode(Gtk.SelectionMode.BROWSE)
     column = Gtk.TreeViewColumn.new()
+    column.set_spacing(2)
     # First cell in the column is for an image...
     cell = Gtk.CellRendererPixbuf()
     column.pack_start(cell, 0)
@@ -139,7 +140,7 @@ def _set_text(column, cell, model, iter, data):
     if element is RELATIONSHIPS:
         text = gettext("<Relationships>")
     else:
-        text = format(element) or "<None>"
+        text = format(element) or gettext("<None>")
     cell.set_property("text", text)
 
 
